"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ItemListing = void 0;
const tslib_1 = require("tslib");
const ethers_1 = require("ethers");
const typechain_1 = require("@motif-foundation/listing/dist/typechain");
const _7018_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/7018.json"));
const addresses_1 = require("./addresses");
const utils_1 = require("./utils");
const itemListingAddresses = {
    motif: _7018_json_1.default.itemListing,
};
class ItemListing {
    constructor(signerOrProvider, chainId, itemAddress) {
        this.chainId = chainId;
        this.readOnly = !ethers_1.Signer.isSigner(signerOrProvider);
        this.signerOrProvider = signerOrProvider;
        const network = (0, utils_1.chainIdToNetworkName)(chainId);
        const address = itemListingAddresses[network];
        this.itemListing = typechain_1.ItemListing__factory.connect(address, signerOrProvider);
        if (itemAddress) {
            const parsedItemAddress = (0, utils_1.validateAndParseAddress)(itemAddress);
            this.itemAddress = parsedItemAddress;
        }
        else {
            this.itemAddress = addresses_1.addresses[network].item;
        }
    }
    async fetchListing(listingId) {
        return this.itemListing.listings(listingId);
    }
    async fetchListingFromTransactionReceipt(receipt) {
        for (const log of receipt.logs) {
            const description = this.itemListing.interface.parseLog(log);
            if (description.args.listingId && log.address === this.itemListing.address) {
                return this.fetchListing(description.args.listingId);
            }
        }
        return null;
    }
    async createListing(tokenId, startsAt, duration, listPrice, listType, intermediary, intermediaryFeePercentages, listingCurrency, tokenAddress = this.itemAddress) {
        return this.itemListing.createListing(tokenId, tokenAddress, startsAt, duration, listPrice, listType, intermediary, intermediaryFeePercentages, listingCurrency);
    }
    async setListingApproval(listingId, approved) {
        return this.itemListing.setListingApproval(listingId, approved);
    }
    async setListingDropApproval(listingId, approved, startsAt) {
        return this.itemListing.setListingDropApproval(listingId, approved, startsAt);
    }
    async setListingListPrice(listingId, listPrice) {
        return this.itemListing.setListingListPrice(listingId, listPrice);
    }
    async createBid(listingId, amount) {
        const { listingCurrency } = await this.itemListing.listings(listingId);
        // If ETH listing, include the ETH in this transaction
        if (listingCurrency === ethers_1.ethers.constants.AddressZero) {
            return this.itemListing.createBid(listingId, amount, { value: amount });
        }
        else {
            return this.itemListing.createBid(listingId, amount);
        }
    }
    async createBidForFixed(listId, amount) {
        const { listingCurrency } = await this.itemListing.lists(listId);
        if (listingCurrency === ethers_1.ethers.constants.AddressZero) {
            return this.itemListing.createBid(listId, amount, { value: amount });
        }
        else {
            return this.itemListing.createBid(listId, amount);
        }
    }
    async endListing(listingId) {
        return this.itemListing.endListing(listingId);
    }
    async cancelListing(listingId) {
        return this.itemListing.cancelListing(listingId);
    }
}
exports.ItemListing = ItemListing;
//# sourceMappingURL=itemListing.js.map