"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployCurrency = exports.approveCurrency = exports.mintCurrency = exports.setupMotif = void 0;
const typechain_1 = require("@motif-foundation/asset/dist/typechain");
const bignumber_1 = require("@ethersproject/bignumber");
const constants_1 = require("@ethersproject/constants");
async function setupMotif(wallet, testWallets) {
    const itemExchange = await (await new typechain_1.ItemExchangeFactory(wallet).deploy()).deployed();
    const itemExchangeAddress = itemExchange.address;
    const item = await (await new typechain_1.ItemFactory(wallet).deploy(itemExchange.address, "Motif", "MOTIF")).deployed();
    const itemAddress = item.address;
    await itemExchange.configure(itemAddress);
    const currency = await (await new typechain_1.BaseErc20Factory(wallet).deploy('TEST', 'TEST', bignumber_1.BigNumber.from(18))).deployed();
    const currencyAddress = currency.address;
    for (const toWallet of testWallets) {
        await mintCurrency(wallet, currencyAddress, toWallet.address, bignumber_1.BigNumber.from('10000000000000000000000'));
        await approveCurrency(toWallet, currencyAddress, itemExchangeAddress);
    }
    return {
        item: itemAddress,
        itemExchange: itemExchangeAddress,
        currency: currencyAddress,
    };
}
exports.setupMotif = setupMotif;
async function mintCurrency(wallet, tokenAdress, to, amount) {
    return typechain_1.BaseErc20Factory.connect(tokenAdress, wallet).mint(to, amount);
}
exports.mintCurrency = mintCurrency;
async function approveCurrency(wallet, tokenAddress, to) {
    return typechain_1.BaseErc20Factory.connect(tokenAddress, wallet).approve(to, constants_1.MaxUint256);
}
exports.approveCurrency = approveCurrency;
async function deployCurrency(wallet, name, symbol, decimals) {
    const currency = await (await new typechain_1.BaseErc20Factory(wallet).deploy(name, symbol, bignumber_1.BigNumber.from(decimals))).deployed();
    return currency.address;
}
exports.deployCurrency = deployCurrency;
//# sourceMappingURL=helpers.js.map